import React, { useState, useRef, useMemo, useEffect } from 'react';
import styles from './index.less';
import { Menu, Grid, Drawer, Tooltip, Row, Col } from 'antd';
import { history, Helmet } from 'umi';
import routes from '../../routes';
import {
  MenuOutlined,
  PlayCircleFilled,
  PhoneFilled,
  WechatFilled,
} from '@ant-design/icons';
import { Scrollbars } from 'react-custom-scrollbars';
import Footer from './footer';

const { useBreakpoint } = Grid;

const colc = { xs: 24, sm: 24, md: 12, lg: 12, xl: 12, xxl: 12 },
  col = { xs: 24, sm: 24, md: 10, lg: 10, xl: 10, xxl: 10 },
  cold = { xs: 24, sm: 24, md: 8, lg: 8, xl: 8, xxl: 8 },
  colds = { xs: 24, sm: 24, md: 12, lg: 8, xl: 8, xxl: 8 },
  cols = { xs: 24, sm: 24, md: 14, lg: 14, xl: 14, xxl: 14 };

const mapTree = (org) => {
  const haveChildren = Array.isArray(org.routes) && org.routes.length > 0;
  if (!org.name || org.hideInMenu) return;
  const children = haveChildren
    ? {
        children: org.routes.map((i) => mapTree(i)),
      }
    : {};

  return {
    key: org.path,
    label: org.name,
    type: org.type,
    ...children,
  };
};

const MenuRender = ({ arrs, mode, activeKey }) => {
  return (
    <Menu
      mode={mode ?? 'horizontal'}
      activeKey={activeKey}
      items={arrs}
      onClick={({ item, key, keyPath, domEvent }) => {
        history.push(key);
      }}
    />
  );
};

function Layout({ children, location }) {
  const [collspan, setcollspan] = useState(false);
  const scrollRef = useRef();
  const screens = useBreakpoint();
  const arrs = useMemo(() => {
    let arr = [];
    routes.map((org) => {
      if (org.name) {
        arr.push(mapTree(org));
      }
    });
    return arr;
  }, []);

  useEffect(() => {
    scrollRef.current.view.scroll({
      top: 0,
      left: 0,
      behavior: 'smooth',
    });
  }, [location.pathname]);

  return (
    <div className={styles.container}>
      <Helmet encodeSpecialCharacters={false}>
        <html lang="en" data-direction="666" />
        <title>江苏南高智能装备创新中心有限公司</title>
      </Helmet>
      <Drawer
        open={collspan}
        title={false}
        maskClosable={true}
        onClose={() => {
          setcollspan(false);
        }}
        closable={false}
        width={260}
      >
        <MenuRender mode="inline" activeKey={location?.pathname} arrs={arrs} />
      </Drawer>
      <header>
        <div style={{ flex: 1 }}>
          {!screens.sm ? (
            <img
              src={require('@/assets/logo.svg')}
              alt=""
              style={{ width: '100%' }}
            />
          ) : (
            <img
              src={require('@/assets/logo.svg')}
              style={{ height: 52 }}
              alt=""
            />
          )}
        </div>

        <div className={styles.menu} style={{ flexShrink: 0 }}>
          {!screens.xl ? (
            <div className={styles.dll}>
              <MenuOutlined
                onClick={() => {
                  setcollspan(!collspan);
                }}
              />
              <Tooltip title="产品演示" placement="bottom">
                <PlayCircleFilled style={{ fontSize: 20, color: '#000000' }} />
              </Tooltip>
            </div>
          ) : (
            <>
              <MenuRender
                activeKey={location?.pathname}
                arrs={arrs}
              ></MenuRender>
              <div
                className="center bglight"
                style={{
                  width: 130,
                  height: 80,
                  marginRight: -24,
                  color: '#fff',
                  cursor: 'pointer',
                }}
              >
                <PlayCircleFilled
                  style={{ fontSize: 20, color: '#ffffff', marginRight: 6 }}
                />
                产品演示
              </div>
            </>
          )}
        </div>
      </header>
      <Scrollbars
        thumbMinSize={10}
        autoHide
        style={{
          width: '100%',
          height: 'calc(100vh - 80px)',
          overflowX: 'hidden',
        }}
        hideTracksWhenNotNeeded={true}
        ref={scrollRef}
      >
        <div className="content">{children}</div>
        <div className={styles.navbar}>
          <Row>
            <Col {...cold}>
              <PhoneFilled />
            </Col>
            <Col {...cold}>
              <WechatFilled />
            </Col>
            <Col {...cold}></Col>
          </Row>
        </div>
        <Footer></Footer>
      </Scrollbars>
    </div>
  );
}

export default Layout;
